==> monodevelop_5.5.0.227.orig.tar.bz2: monodevelop-5.5/src/core/MonoDevelop.Ide/MonoDevelop.Ide.Templates/ProjectTemplatePackageReference.cs <==
//
// ProjectTemplatePackageReference.cs
//
// Author:
//       Matt Ward <matt.ward@xamarin.com>
//
// Copyright (c) 2014 Xamarin Inc. (http://xamarin.com)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Xml;

namespace MonoDevelop.Ide.Templates
{
	public class ProjectTemplatePackageReference
	{
		public static ProjectTemplatePackageReference Create (XmlElement xmlElement)
		{
			return new ProjectTemplatePackageReference {
				Id = GetAttribute (xmlElement, "id"),
				Version = GetAttribute (xmlElement, "version")
			};
		}

		public string Id { get; private set; }
		public string Version { get; private set; }

		static string GetAttribute (XmlElement xmlElement, string attributeName)
		{
			foreach (XmlAttribute attribute in xmlElement.Attributes) {
				if (attributeName.Equals (attribute.Name, StringComparison.OrdinalIgnoreCase)) {
					return attribute.Value;
				}
			}
			return "";
		}
	}
}

==> monodevelop_5.10.0.871.orig.tar.bz2: monodevelop-5.10/src/core/MonoDevelop.Ide/MonoDevelop.Ide.Templates/ProjectTemplatePackageReference.cs <==
//
// ProjectTemplatePackageReference.cs
//
// Author:
//       Matt Ward <matt.ward@xamarin.com>
//
// Copyright (c) 2014 Xamarin Inc. (http://xamarin.com)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Xml;

namespace MonoDevelop.Ide.Templates
{
	public class ProjectTemplatePackageReference
	{
		public static ProjectTemplatePackageReference Create (XmlElement xmlElement)
		{
			return new ProjectTemplatePackageReference {
				Id = GetAttribute (xmlElement, "id"),
				Version = GetAttribute (xmlElement, "version"),
				CreateCondition = GetAttribute (xmlElement, "if")
			};
		}

		public string Id { get; private set; }
		public string Version { get; private set; }
		public string CreateCondition { get; private set; }

		static string GetAttribute (XmlElement xmlElement, string attributeName)
		{
			foreach (XmlAttribute attribute in xmlElement.Attributes) {
				if (attributeName.Equals (attribute.Name, StringComparison.OrdinalIgnoreCase)) {
					return attribute.Value;
				}
			}
			return "";
		}
	}
}
